@@ -2,6 +2,7 @@ from typing import Optional
 
 from globus_automate_client.action_client import ActionClient
 from globus_automate_client.cli.auth import CLIENT_ID, get_cli_authorizer
+from globus_automate_client.cli.rich_rendering import live_content
 from globus_automate_client.flows_client import (
     MANAGE_FLOWS_SCOPE,
     PROD_FLOWS_BASE_URL,
@@ -55,7 +56,11 @@ def cli_authorizer_callback(**kwargs):
     flow_url = kwargs["flow_url"]
     flow_scope = kwargs["flow_scope"]
     client_id = kwargs["client_id"]
-    return get_cli_authorizer(flow_url, flow_scope, client_id)
+
+    live_content.pause_live()
+    authorizer = get_cli_authorizer(flow_url, flow_scope, client_id)
+    live_content.resume_live()
+    return authorizer
 
 
 def create_flows_client(
